@@ -8,28 +8,84 @@ from chainladder.utils.sparse import sp
 
 def _get_full_expectation(cdf_, ultimate_):
     """ Private method that builds full expectation"""
-    xp = ultimate_.get_array_module()
-    cdf = cdf_.copy()
-    if cdf.shape[2] == 1:
-        cdf.values = cdf_.get_array_module().repeat(
-            cdf.values[..., 0:1, :], ultimate_.shape[-2], 2
-        )
-        cdf.odims = ultimate_.odims
-    cdf.valuation_date = ultimate_.valuation_date
     full = ultimate_.copy()
-    full.values = xp.concatenate(((full / cdf).values, full.values), -1)
+    xp = full.get_array_module()
+    full.values = xp.repeat(full.values, cdf_.shape[-1], -1)
     offset = {"Y": 12, "Q": 3, "M": 1}[cdf_.development_grain]
     ddims = ([cdf_.ddims[0] - offset], list(cdf_.ddims[:-1]), [9999])
     full.ddims = np.concatenate(ddims)
+    if len(cdf_) != len(ultimate_) and len(cdf_.index) > 1:
+        if hasattr(ultimate_, 'group_index'):
+            group_index = ultimate_.group_index
+        else:
+            group_index = ultimate_.index
+        level = list(
+            set(group_index.columns).intersection(
+            set(cdf_.key_labels)))
+        idx = group_index.merge(
+            cdf_.index.reset_index(),
+            how='left', on=level)['index'].values.astype(int)
+        cdf = cdf_.values[list(idx), ...]
+    else:
+        cdf = cdf_.values
+    full.values = full.values / cdf
+    full.values = xp.concatenate((full.values, ultimate_.set_backend(full.array_backend).values), -1)
     return full
 
 
-def _get_full_triangle(full_expectation_, triangle_):
+def _get_full_triangle(X, ultimate, expectation=None, n_iters=None):
     """ Private method that builds full triangle"""
-    full = full_expectation_
-    full = triangle_ + full - full[full.valuation <= triangle_.valuation_date]
-    full.vdims = triangle_.vdims
-    return full
+    cdf = X.ldf_.copy()
+    xp = cdf.get_array_module()
+    if cdf.shape[2] == 1:
+        cdf.values = xp.repeat(cdf.values, len(X.origin), 2)
+    cdf.odims = X.odims
+    if len(cdf) != len(ultimate) and len(cdf.index) > 1:
+        level = list(
+            set(ultimate.group_index.columns).intersection(
+            set(cdf.key_labels)))
+        idx = ultimate.group_index.merge(
+            cdf.index.reset_index(),
+            how='left', on=level)['index'].values.astype(int)
+        cdf.values = cdf.values[list(idx), ...]
+    else:
+        cdf.values = cdf.values
+    cdf.kdims = ultimate.kdims
+    cdf.key_labels = ultimate.key_labels
+    cdf = cdf[cdf.valuation<=X.valuation_date] * 0 + 1 + cdf[cdf.valuation>X.valuation_date]
+    cdf.values = cdf.values.cumprod(3)
+
+    if len(cdf) != len(ultimate) and len(cdf.index) > 1:
+        if hasattr(ultimate, 'group_index'):
+            group_index = ultimate.group_index
+        else:
+            group_index = ultimate.index
+        level = list(
+            set(group_index.columns).intersection(
+            set(cdf.key_labels)))
+        idx = group_index.merge(
+            cdf.index.reset_index(),
+            how='left', on=level)['index'].values.astype(int)
+        cdf.values = cdf.values[list(idx), ...]
+    else:
+        cdf.values = cdf.values
+    cdf.kdims = ultimate.kdims
+    cdf.key_labels = ultimate.key_labels
+    cdf = (1 - 1 / cdf)
+    ld = X.latest_diagonal
+    ld.valuation_date = ld.valuation.max()
+    ld = cdf * 0 + ld.values
+    if n_iters is not None:
+        a = (X.latest_diagonal * 0 + expectation.values) / X.cdf_ * X.ldf_
+        complement = xp.nansum(cdf.values[None] ** xp.arange(n_iters)[:, None, None, None, None], 0)
+        new_run_off = (( a * (cdf ** n_iters)) + (ld * complement).values)
+    else:
+        complement = (1 / (1 - cdf))
+        new_run_off = (ld * complement)
+    new_run_off = new_run_off[new_run_off.valuation>X.valuation_date] + X
+    new_run_off.is_pattern = False
+    new_run_off.is_cumulative = True
+    return new_run_off
 
 
 class Common:
@@ -77,9 +133,13 @@ class Common:
                 + " object has no attribute 'full_triangle_'"
             )
         if hasattr(self, "X_"):
-            return _get_full_triangle(self.full_expectation_, self.X_)
+            X = self.X_
         else:
-            return _get_full_triangle(self.full_expectation_, self)
+            X = self
+        if hasattr(self, 'n_iters'):
+            return _get_full_triangle(X, self.ultimate_, self.expectation_, self.n_iters)
+        else:
+            return _get_full_triangle(X, self.ultimate_)
 
     def pipe(self, func, *args, **kwargs):
         return func(self, *args, **kwargs)
