@@ -18,6 +18,8 @@ class BornhuetterFerguson(Benktander):
         bootstrap model, the model samples aprioris from a lognormal distribution
         using this argument as a standard deviation.
     random_state : int, RandomState instance or None, optional (default=None)
+        Seed for sampling from the apriori distribution.  This is ignored when
+        using as a deterministic method.
         If int, random_state is the seed used by the random number generator;
         If RandomState instance, random_state is the random number generator;
         If None, the random number generator is the RandomState instance used
@@ -56,3 +58,20 @@ class BornhuetterFerguson(Benktander):
         self.n_iters = 1
         super().fit(X, y, sample_weight)
         return self
+
+    def predict(self, X, sample_weight=None):
+        """Predicts the Bornhuetter-Ferguson ultimate on a new triangle **X**
+
+        Parameters
+        ----------
+        X : Triangle
+            Loss data to which the model will be applied.
+        sample_weight : Triangle
+            Required exposure to be used in the calculation.
+
+        Returns
+        -------
+        X_new: Triangle
+            Loss data with Bornhuetter-Ferguson ultimate applied
+        """
+        return super().predict(X, sample_weight)
