@@ -21,7 +21,7 @@ class TailBondy(TailBase):
         age can be used.
     attachment_age: int (default=None)
         The age at which to attach the fitted curve.  If None, then the latest
-        age is used. Measures of variability from original `ldf_` are retained
+        age is used. Measures of variability from original ``ldf_`` are retained
         when being used in conjunction with the MackChainladder method.
 
     Attributes
@@ -41,7 +41,7 @@ class TailBondy(TailBase):
     std_err_ : Triangle
         std_err with tail factor applied
     earliest_ldf_ : DataFrame
-        Based on the `earliest_age` selection, this shows the seed `ldf_` used
+        Based on the ``earliest_age`` selection, this shows the seed ``ldf_`` used
         in fitting the Bondy exponent.
 
     See also
@@ -134,13 +134,7 @@ class TailBondy(TailBase):
             ),
             axis=-1,
         )
-        sigma, std_err = self._get_tail_stats(obj)
-        self.sigma_.values = xp.concatenate(
-            (self.sigma_.values[..., :-1], sigma[..., -1:]), axis=-1
-        )
-        self.std_err_.values = xp.concatenate(
-            (self.std_err_.values[..., :-1], std_err[..., -1:]), axis=-1
-        )
+        self._get_tail_stats(obj)
         if backend == "cupy":
             self = self.set_backend(backend, inplace=True, deep=True)
         return self
