@@ -7,12 +7,13 @@ from chainladder.utils.cupy import cp
 from chainladder.utils.sparse import sp
 from scipy.sparse import coo_matrix
 import joblib
+import dill
 import json
 import os
 import copy
-from chainladder.core.triangle import Triangle
-from chainladder.workflow import Pipeline
 from sklearn.utils import deprecated
+from patsy import dmatrix
+from sklearn.base import BaseEstimator, TransformerMixin
 
 
 def load_sample(key, *args, **kwargs):
@@ -26,6 +27,8 @@ def load_sample(key, *args, **kwargs):
     	pandas.DataFrame of the loaded dataset.
 
     """
+    from chainladder import Triangle
+
     path = os.path.dirname(os.path.abspath(__file__))
     origin = "origin"
     development = "development"
@@ -51,6 +54,10 @@ def load_sample(key, *args, **kwargs):
         development = "DevelopmentYear"
         index = ["LOB"]
         columns = ["Incurred", "Paid", "Reported", "Closed"]
+    if key.lower() == "xyz":
+        origin = "AccidentYear"
+        development = "DevelopmentYear"
+        columns = ["Incurred", "Paid", "Reported", "Closed", "Premium"]
     if key.lower() in ["liab", "auto"]:
         index = ["lob"]
     if key.lower() in ["cc_sample", "ia_sample"]:
@@ -80,27 +87,18 @@ def load_dataset(key, *args, **kwargs):
 
 
 def read_pickle(path):
-    return joblib.load(path)
+    out = joblib.load(path)
+    try:
+        out.virtual_columns = dill.loads(out.virtual_columns)
+    except:
+        from chainladder.core.slice import VirtualColumns
+        out.virtual_columns = VirtualColumns(out)
+    return out
 
 
 def read_json(json_str, array_backend=None):
-    def sparse_in(json_str, dtype, shape):
-        k, v, o, d = shape
-        x = json.loads(json_str)
-        y = np.array(
-            [tuple([int(idx) for idx in item[1:-1].split(",")]) for item in x.keys()]
-        )
-        new = (
-            coo_matrix(
-                (np.array(list(x.values())), (y[:, 0], y[:, 1])),
-                shape=(k * v * o, d),
-                dtype=dtype,
-            )
-            .toarray()
-            .reshape(k, v, o, d)
-        )
-        new[new == 0] = np.nan
-        return new
+    from chainladder import Triangle
+    from chainladder.workflow import Pipeline
 
     if array_backend is None:
         from chainladder import ARRAY_BACKEND
@@ -119,47 +117,28 @@ def read_json(json_str, array_backend=None):
                 for item in json_dict
             ]
         )
-    elif "kdims" in json_dict.keys():
-        tri = Triangle()
-        tri.array_backend = array_backend
-        arrays = ["kdims", "vdims", "odims", "ddims"]
-        for array in arrays:
-            setattr(
-                tri,
-                array,
-                np.array(json_dict[array]["array"], dtype=json_dict[array]["dtype"]),
-            )
-        shape = (len(tri.kdims), len(tri.vdims), len(tri.odims), len(tri.ddims))
-        properties = [
-            "key_labels",
-            "origin_grain",
-            "development_grain",
-            "is_cumulative",
-        ]
-        for prop in properties:
-            setattr(tri, prop, json_dict[prop])
-        if json_dict.get("is_val_tri", False):
-            tri.ddims = pd.PeriodIndex(
-                tri.ddims, freq=tri.development_grain
-            ).to_timestamp(how="e")
-        tri.valuation_date = (
-            pd.to_datetime(json_dict["valuation_date"], format="%Y-%m-%d")
-            .to_period("M")
-            .to_timestamp(how="e")
+    elif "metadata" in json_dict.keys():
+        j = json.loads(json_str)
+        y = pd.read_json(j["data"], orient="split", date_unit="ns")
+        y["origin"] = pd.to_datetime(y["origin"])
+        y.columns= [
+            c if c != 'valuation' else 'development' for c in y.columns]
+        y["development"] = pd.to_datetime(y["development"])
+        index = list(y.columns[: list(y.columns).index("origin")])
+        columns = list(y.columns[list(y.columns).index("development") + 1 :])
+        tri = Triangle(
+            y,
+            origin="origin",
+            development="development",
+            index=index,
+            columns=columns,
+            pattern=json.loads(j["metadata"])["is_pattern"],
         )
-        if json_dict["values"].get("sparse", None):
-            tri.values = sparse_in(
-                json_dict["values"]["array"], json_dict["values"]["dtype"], shape
-            )
-        else:
-            tri.values = np.array(
-                json_dict["values"]["array"], dtype=json_dict["values"]["dtype"]
-            )
-        if array_backend == "cupy":
-            tri.values = cp.array(tri.values)
-        if tri.is_cumulative:
-            tri.is_cumulative = False
+        if json.loads(j["metadata"])["is_val_tri"]:
+            tri = tri.dev_to_val()
+        if json.loads(j["metadata"])["is_cumulative"]:
             tri = tri.incr_to_cum()
+        tri = tri[json.loads(j["metadata"])["columns"]].sort_index()
         if "sub_tris" in json_dict.keys():
             for k, v in json_dict["sub_tris"].items():
                 setattr(tri, k, read_json(v, array_backend))
@@ -169,8 +148,10 @@ def read_json(json_str, array_backend=None):
                 if len(df.columns) == 1:
                     df = df.iloc[:, 0]
                 setattr(tri, k, df)
-        tri._set_slicers()
-        return tri
+        if array_backend:
+            return tri.set_backend(array_backend)
+        else:
+            return tri
     else:
         import chainladder as cl
 
@@ -180,28 +161,43 @@ def read_json(json_str, array_backend=None):
 def parallelogram_olf(
     values, date, start_date=None, end_date=None, grain="M", vertical_line=False
 ):
-    """ Parallelogram approach to on-leveling.  Need to fix return grain
+    """ Parallelogram approach to on-leveling.
+
+    Ar
     """
     date = pd.to_datetime(date)
     if not start_date:
-        start_date = "{}-01-01".format(date.min().year - 1)
+        start_date = "{}-01-01".format(date.min().year)
     if not end_date:
-        end_date = "{}-12-31".format(date.max().year + 1)
-    date_idx = pd.date_range(start_date, end_date)
+        end_date = "{}-12-31".format(date.max().year)
+    start_date = pd.to_datetime(start_date) - pd.tseries.offsets.DateOffset(days=1)
+    date_idx = pd.date_range(
+        start_date - pd.tseries.offsets.DateOffset(years=1), end_date
+    )
     y = pd.Series(np.array(values), np.array(date))
     y = y.reindex(date_idx, fill_value=0)
     idx = np.cumprod(y.values + 1)
     idx = idx[-1] / idx
     y = pd.Series(idx, y.index)
+    y = y[~((y.index.day == 29) & (y.index.month == 2))]
     if not vertical_line:
-        y = y.to_frame().rolling(365).mean()
+        y = y.rolling(365).mean()
+        y = (y + y.shift(1).values) / 2
+    y = y.iloc[366:]
     y = y.groupby(y.index.to_period(grain)).mean().reset_index()
     y.columns = ["Origin", "OLF"]
     y["Origin"] = y["Origin"].astype(str)
     return y.set_index("Origin")
 
 
-def concat(objs, axis):
+def set_common_backend(objs):
+    from chainladder import ARRAY_PRIORITY as priority
+
+    backend = priority[np.min([priority.index(i.array_backend) for i in objs])]
+    return [i.set_backend(backend) for i in objs]
+
+
+def concat(objs, axis, ignore_index=False):
     """ Concatenate Triangle objects along a particular axis.
 
     Parameters
@@ -210,23 +206,34 @@ def concat(objs, axis):
         A list or tuple of Triangle objects to concat. All non-concat axes must
         be identical and all elements of the concat axes must be unique.
     axis : string or int
-        The axis along which to concatenate.
+        The axis to concatenate along.
+    ignore_index : bool, default False
+        If True, do not use the index values along the concatenation axis. The
+        resulting axis will be labeled 0, …, n - 1. This is useful if you are
+        concatenating objects where the concatenation axis does not have
+        meaningful indexing information. Note the index values on the other
+        axes are still respected in the join.
 
     Returns
     -------
     Updated triangle
     """
+    objs = set_common_backend(objs)
     xp = objs[0].get_array_module()
     axis = objs[0]._get_axis(axis)
     mapper = {0: "kdims", 1: "vdims", 2: "odims", 3: "ddims"}
     for k, v in mapper.items():
         if k != axis:  # All non-concat axes must be identical
-            assert np.all(
-                np.array([getattr(obj, mapper[k]) for obj in objs])
-                == getattr(objs[0], mapper[k])
-            )
+            a = np.array([getattr(obj, mapper[k]) for obj in objs])
+            assert np.all(a == a[0])
         else:  # All elements of concat axis must be unique
-            new_axis = np.concatenate([getattr(obj, mapper[axis]) for obj in objs])
+            if ignore_index:
+                new_axis = np.arange(
+                    np.sum([len(getattr(obj, mapper[axis])) for obj in objs])
+                )
+                new_axis = new_axis[:, None] if axis == 0 else new_axis
+            else:
+                new_axis = np.concatenate([getattr(obj, mapper[axis]) for obj in objs])
             if axis == 0:
                 assert len(pd.DataFrame(new_axis).drop_duplicates()) == len(new_axis)
             else:
@@ -234,6 +241,11 @@ def concat(objs, axis):
     out = copy.deepcopy(objs[0])
     out.values = xp.concatenate([obj.values for obj in objs], axis=axis)
     setattr(out, mapper[axis], new_axis)
+    if ignore_index and axis == 0:
+        out.key_labels = ["Index"]
+    out.valuation_date = pd.Series([obj.valuation_date for obj in objs]).max()
+    if out.ddims.dtype == "datetime64[ns]" and type(out.ddims) == np.ndarray:
+        out.ddims = pd.DatetimeIndex(out.ddims)
     out._set_slicers()
     return out
 
@@ -243,10 +255,9 @@ def num_to_nan(arr):
     backend = arr.__class__.__module__.split(".")[0]
     if backend == "sparse":
         if arr.fill_value == 0 or sp.isnan(arr.fill_value):
-            arr.fill_value = sp.nan
             arr.coords = arr.coords[:, arr.data != 0]
             arr.data = arr.data[arr.data != 0]
-            arr = sp(arr)
+            arr = sp(coords=arr.coords, data=arr.data, fill_value=sp.nan, shape=arr.shape)
         else:
             arr = sp(num_to_nan(np.nan_to_num(arr.todense())), fill_value=sp.nan)
     else:
@@ -261,3 +272,39 @@ def minimum(x1, x2):
 
 def maximum(x1, x2):
     return x1.maximum(x2)
+
+class PatsyFormula(BaseEstimator, TransformerMixin):
+    """ A sklearn-style Transformer for patsy formulas.
+
+    PatsyFormula allows for R-style formula preprocessing of the ``design_matrix``
+    of a machine learning algorithm. It's particularly useful with the `DevelopmentML`
+    and `TweedieGLM` estimators.
+
+    Parameters
+    -----------
+
+    formula : str
+        A string representation of the regression model X features.
+
+    Attributes
+    ------------
+    design_info_ :
+        The patsy instructions for generating the design_matrix, X.
+
+    """
+    def __init__(self, formula=None):
+        self.formula = formula
+
+    def _check_X(self, X):
+        from chainladder.core import Triangle
+        if isinstance(X, Triangle):
+            raise AttributeError("X must be a pandas dataframe, not a Triangle")
+
+    def fit(self, X, y=None, sample_weight=None):
+        self._check_X(X)
+        self.design_info_ = dmatrix(self.formula, X).design_info
+        return self
+
+    def transform(self, X):
+        self._check_X(X)
+        return dmatrix(self.design_info_, X)
